@@ -111,9 +111,10 @@ def qubits(clArgs=None):
     explosionDaysFromSettings,
     extendLightCurveTail,
     relativeSNRates,
-    redshiftLimit,
+    lowerRedshiftLimit,
+    upperRedshiftLimit,
     redshiftResolution,
-    observeFrameFilter,
+    restFrameFilter,
     kCorrectionTemporalResolution,
     kCorPolyOrder,
     kCorMinimumDataPoints,
@@ -125,7 +126,7 @@ def qubits(clArgs=None):
     snLightCurves,
     surveyArea,
     CCSNRateFraction,
-    PISNToCCSNRateFraction,
+    transientToCCSNRateFraction,
     extraSurveyConstraints,
     lightCurvePolyOrder,
     logLevel) = cu.read_in_survey_parameters(
@@ -183,21 +184,21 @@ def qubits(clArgs=None):
                 log,
                 pathToOutputDirectory=pathToOutputDirectory,
                 pathToSpectralDatabase=pathToSpectralDatabase,
-                observeFrameFilter=observeFrameFilter,
+                restFrameFilter=restFrameFilter,
                 temporalResolution=kCorrectionTemporalResolution,
                 redshiftResolution=redshiftResolution,
-                redshiftLower=0.0,
-                redshiftUpper=redshiftLimit+redshiftResolution)
+                redshiftLower=lowerRedshiftLimit,
+                redshiftUpper=upperRedshiftLimit+redshiftResolution)
         log.info('generating the kcorrection polynomials')
         dg.generate_kcorrection_polynomial_database(
                 log,
                 pathToOutputDirectory=pathToOutputDirectory,
-                observeFrameFilter=observeFrameFilter,
+                restFrameFilter=restFrameFilter,
                 kCorPolyOrder=kCorPolyOrder,  # ORDER OF THE POLYNOMIAL TO FIT
                 kCorMinimumDataPoints=kCorMinimumDataPoints,
                 redshiftResolution=redshiftResolution,
-                redshiftLower=0.0,
-                redshiftUpper=redshiftLimit+redshiftResolution,
+                redshiftLower=lowerRedshiftLimit,
+                redshiftUpper=upperRedshiftLimit+redshiftResolution,
                 plot=programSettings['Generate KCorrection Plots'])
 
     if programSettings['Run the Simulation']:
@@ -206,7 +207,8 @@ def qubits(clArgs=None):
        redshiftArray = u.random_redshift_array(
            log,
            sampleNumber,
-           redshiftLimit,
+           lowerRedshiftLimit,
+           upperRedshiftLimit,
            redshiftResolution=redshiftResolution,
            pathToOutputPlotDirectory=pathToOutputPlotDirectory,
            plot=programSettings['Plot Simulation Helper Plots'])
@@ -274,9 +276,10 @@ def qubits(clArgs=None):
            kCorrectionArray = kCorrectionArray,
            hostExtinctionArray = hostExtinctionArray,
            galacticExtinctionArray = galacticExtinctionArray,
-           observeFrameFilter=observeFrameFilter,
+           restFrameFilter=restFrameFilter,
            pathToOutputDirectory=pathToOutputDirectory,
            pathToOutputPlotDirectory=pathToOutputPlotDirectory,
+           polyOrder=lightCurvePolyOrder,
            plot=programSettings['Plot Simulation Helper Plots'])
 
        log.info('generating the survey observation cadence')
@@ -350,11 +353,11 @@ def qubits(clArgs=None):
                                         snSurveyDiscoveryTimes,
                                         redshifts,
                                         surveyCadenceSettings=surveyCadenceSettings,
-                                        redshiftLimit=redshiftLimit,
+                                        upperRedshiftLimit=upperRedshiftLimit,
                                         redshiftResolution=redshiftResolution,
                                         surveyArea=surveyArea,
                                         CCSNRateFraction=CCSNRateFraction,
-                                        PISNToCCSNRateFraction=PISNToCCSNRateFraction,
+                                        transientToCCSNRateFraction=transientToCCSNRateFraction,
                                         peakAppMagList=peakAppMagList,
                                         snCampaignLengthList=snCampaignLengthList,
                                         extraSurveyConstraints=extraSurveyConstraints,
@@ -362,7 +365,7 @@ def qubits(clArgs=None):
         result_log += """
 ## Results ##
 
-This simulated survey discovered a total of **%s** PISNe per year. An extra **%s** PISNe were detected but deemed too faint to constrain a positive PISN identification and a further **%s** PISNe where detected but an observational campaign of more than **%s** days could not be completed to ensure identification. See below for the various output plots.
+This simulated survey discovered a total of **%s** transients per year. An extra **%s** transients were detected but deemed too faint to constrain a positive transient identification and a further **%s** transients where detected but an observational campaign of more than **%s** days could not be completed to ensure identification. See below for the various output plots.
 
         """ % (totalRate, tooFaintRate, shortCampaignRate, extraSurveyConstraints["Observable for at least ? number of days"])
         cadenceWheelLink = r.plot_cadence_wheel(
